@@ -16,6 +16,8 @@
 #     You should have received a copy of the GNU Lesser General Public License
 #     along with LEPL.  If not, see <http://www.gnu.org/licenses/>.
 
+# pylint: disable-msg=C0301
+
 '''
 LEPL is a parser library written in Python.
   
@@ -103,14 +105,19 @@ Running this gives the result::
 '''
 
 from lepl.config import Configuration
+from lepl.contrib.matchers import SmartSeparator2
+from lepl.error import *
+from lepl.functions import *
 from lepl.memo import * 
 from lepl.node import *
 from lepl.operators import * 
 from lepl.parser import *
-from lepl.regexp import *
 from lepl.stream import *
+from lepl.lexer.matchers import Token, LexerError, RuntimeLexerError
+from lepl.lexer.rewriters import lexer_rewriter
 from lepl.manager import *
 from lepl.matchers import *
+from lepl.regexp.core import RegexpError
 from lepl.regexp.matchers import NfaRegexp, DfaRegexp
 from lepl.regexp.rewriters import regexp_rewriter
 from lepl.regexp.unicode import UnicodeAlphabet
@@ -120,6 +127,13 @@ from lepl.trace import *
 __all__ = [
         # config
         'Configuration',
+        # contrib.matchers
+        'SmartSeparator2',
+        # error
+        'make_error',
+        'raise_error',
+        'Error',
+        'throw',
         # match
         'Empty',
         'Repeat',
@@ -130,7 +144,10 @@ __all__ = [
         'Literal',
         'Empty',
         'Lookahead',
+        'Columns',
+        # functions
         'Apply',
+        'args',
         'KApply',
         'Regexp', 
         'Delayed', 
@@ -171,6 +188,7 @@ __all__ = [
         'DropEmpty',
         'Literals',
         'String',
+        'SkipTo',
         'GREEDY',
         'NON_GREEDY',
         'DEPTH_FIRST',
@@ -179,17 +197,20 @@ __all__ = [
         'Node',
         'make_dict',
         'join_with',
-        'make_error',
-        'raise_error',
-        'Error',
-        'throw',
         # stream
-        'Stream',
+        'DEFAULT_STREAM_FACTORY',
         # operators
         'Override',
         'Separator',
+        'SmartSeparator1',
         # parser
         'Configuration',
+        # lexer.matchers
+        'Token',
+        'LexerError',
+        'RuntimeLexerError',
+        # lexer.rewriters
+        'lexer_rewriter',
         # manager
         'GeneratorManager',
         # trace
@@ -199,6 +220,8 @@ __all__ = [
         # memo,
         'RMemo',
         'LMemo',
+        # regexp.core
+        'RegexpError',
         # regexp.matchers
         'NfaRegexp',
         'DfaRegexp',
@@ -214,9 +237,9 @@ __all__ = [
         'context_memoize',
         'optimize_or']
 
-__version__ = '2.3.5'
+__version__ = '3.2'
 
 if __version__.find('b') > -1:
     from logging import getLogger, basicConfig, WARN
-#    basicConfig(level=WARN)
+    #basicConfig(level=WARN)
     getLogger('lepl').warn('You are using a BETA version of LEPL.')
