@@ -40,22 +40,22 @@ For more background, please see the `manual <../index.html>`_.
 # (consistent interfaces)
 # pylint: disable-msg=E1101
 # (_args create attributes)
+# pylint: disable-msg=R0901, R0904, W0142
+# lepl conventions
 
 from abc import ABCMeta
 from collections import deque
 from re import compile as compile_
 
 from lepl.config import Configuration
-from lepl.error import raise_error
 from lepl.graph import ArgAsAttributeMixin, PostorderWalkerMixin, \
     ConstructorStr, GraphStr
 from lepl.manager import _GeneratorManager
 from lepl.node import Node
 from lepl.operators import OperatorMixin, OPERATORS, DefaultNamespace, Matcher
 from lepl.parser import make_parser, make_matcher, tagged
-from lepl.stream import SequenceByLine
 from lepl.trace import _TraceResults
-from lepl.support import assert_type, lmap, LogMixin
+from lepl.support import lmap, LogMixin
 
 
 # pylint: disable-msg=W0105
@@ -98,7 +98,7 @@ class OperatorMatcher(OperatorMixin, BaseMatcher):
 
     def __str__(self):
         visitor = ConstructorStr()
-        return visitor.postprocess(self.postorder(visitor, Matcher))
+        return self.postorder(visitor, Matcher)
     
     def __repr__(self):
         return '<%s>' % self.__class__.__name__
@@ -108,158 +108,163 @@ class OperatorMatcher(OperatorMixin, BaseMatcher):
         An ASCII tree for display.
         '''
         visitor = GraphStr()
-        return visitor.postprocess(self.postorder(visitor))
+        return self.postorder(visitor)
     
-    def file_parser(self, config=None):
+    def file_parser(self, config=None, **kargs):
         '''
-        Construct a parser for file objects that uses a `SequenceByLine()` 
+        Construct a parser for file objects that uses a stream 
         internally and returns a single result.
         '''
-        return make_parser(self, SequenceByLine.from_file, 
-                           config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_parser(self, config.stream.from_file, config, kargs)
     
-    def list_parser(self, config=None):
+    def items_parser(self, config=None, **kargs):
         '''
-        Construct a parser for lists that uses a `SequenceByLine()` 
+        Construct a parser for a sequence of times (an item is something
+        that would be matched by `Any`) that uses a stream internally and 
+        returns a single result.
+        '''
+        config = Configuration.default(config)
+        return make_parser(self, config.stream.from_items, config, kargs) 
+    
+    def path_parser(self, config=None, **kargs):
+        '''
+        Construct a parser for a file that uses a stream 
         internally and returns a single result.
         '''
-        return make_parser(self, SequenceByLine.from_list, 
-                           config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_parser(self, config.stream.from_path, config, kargs) 
     
-    def path_parser(self, config=None):
+    def string_parser(self, config=None, **kargs):
         '''
-        Construct a parser for a file that uses a `SequenceByLine()` 
+        Construct a parser for strings that uses a stream 
         internally and returns a single result.
         '''
-        return make_parser(self, SequenceByLine.from_path, 
-                           config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_parser(self, config.stream.from_string, config, kargs) 
     
-    def string_parser(self, config=None):
-        '''
-        Construct a parser for strings that uses a `SequenceByLine()` 
-        internally and returns a single result.
-        '''
-        return make_parser(self, SequenceByLine.from_string, 
-                           config if config else Configuration.default())
-    
-    def null_parser(self, config=None):
+    def null_parser(self, config=None, **kargs):
         '''
         Construct a parser for strings and lists that returns a single result
         (this does not use streams).
         '''
-        return make_parser(self, SequenceByLine.null, 
-                           config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_parser(self, config.stream.null, config, kargs) 
     
-    def parse_file(self, file_, config=None):
+    
+    def parse_file(self, file_, config=None, **kargs):
         '''
         Parse the contents of a file, returning a single match and using a
-        `SequenceByLine()` internally.
+        stream internally.
         '''
-        return self.file_parser(config)(file_)
+        return self.file_parser(config, **kargs)(file_)
         
-    def parse_list(self, list_, config=None):
+    def parse_items(self, list_, config=None, **kargs):
         '''
-        Parse the contents of a list, returning a single match and using a
-        `SequenceByLine()` internally.
+        Parse the contents of a sequence of items (an item is something
+        that would be matched by `Any`), returning a single match and using a
+        stream internally.
         '''
-        return self.list_parser(config)(list_)
+        return self.items_parser(config, **kargs)(list_)
         
-    def parse_path(self, path, config=None):
+    def parse_path(self, path, config=None, **kargs):
         '''
         Parse the contents of a file, returning a single match and using a
-        `SequenceByLine()` internally.
+        stream internally.
         '''
-        return self.path_parser(config)(path)
+        return self.path_parser(config, **kargs)(path)
         
-    def parse_string(self, string, config=None):
+    def parse_string(self, string, config=None, **kargs):
         '''
         Parse the contents of a string, returning a single match and using a
-        `SequenceByLine()` internally.
+        stream internally.
         '''
-        return self.string_parser(config)(string)
+        return self.string_parser(config, **kargs)(string)
     
-    def parse(self, stream, config=None):
+    def parse(self, stream, config=None, **kargs):
         '''
         Parse the contents of a string or list, returning a single match (this
         does not use streams).
         '''
-        return self.null_parser(config)(stream)
+        return self.null_parser(config, **kargs)(stream)
     
     
-    def file_matcher(self, config=None):
+    def file_matcher(self, config=None, **kargs):
         '''
         Construct a parser for file objects that returns a sequence of matches
-        and uses a `SequenceByLine()` internally.
+        and uses a stream internally.
         '''
-        return make_matcher(self, SequenceByLine.from_file, 
-                            config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_matcher(self, config.stream.from_file, config, kargs) 
     
-    def list_matcher(self, config=None):
+    def items_matcher(self, config=None, **kargs):
         '''
-        Construct a parser for lists that returns a sequence of matches
-        and uses a `SequenceByLine()` internally.
+        Construct a parser for a sequence of items (an item is something that
+        would be matched by `Any`) that returns a sequence of matches
+        and uses a stream internally.
         '''
-        return make_matcher(self, SequenceByLine.from_list, 
-                            config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_matcher(self, config.stream.from_items, config, kargs) 
     
-    def path_matcher(self, config=None):
+    def path_matcher(self, config=None, **kargs):
         '''
         Construct a parser for a file that returns a sequence of matches
-        and uses a `SequenceByLine()` internally.
+        and uses a stream internally.
         '''
-        return make_matcher(self, SequenceByLine.from_path, 
-                            config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_matcher(self, config.stream.from_path, config, kargs) 
     
-    def string_matcher(self, config=None):
+    def string_matcher(self, config=None, **kargs):
         '''
         Construct a parser for strings that returns a sequence of matches
-        and uses a `SequenceByLine()` internally.
+        and uses a stream internally.
         '''
-        return make_matcher(self, SequenceByLine.from_string, 
-                            config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_matcher(self, config.stream.from_string, config, kargs) 
 
-    def null_matcher(self, config=None):
+    def null_matcher(self, config=None, **kargs):
         '''
         Construct a parser for strings and lists list objects that returns a s
         equence of matches (this does not use streams).
         '''
-        return make_matcher(self, SequenceByLine.null, 
-                            config if config else Configuration.default())
+        config = Configuration.default(config)
+        return make_matcher(self, config.stream.null, config, kargs) 
 
-    def match_file(self, file_, config=None):
+    def match_file(self, file_, config=None, **kargs):
         '''
         Parse the contents of a file, returning a sequence of matches and using 
-        a `SequenceByLine()` internally.
+        a stream internally.
         '''
-        return self.file_matcher(config)(file_)
+        return self.file_matcher(config, **kargs)(file_)
         
-    def match_list(self, list_, config=None):
+    def match_items(self, list_, config=None, **kargs):
         '''
-        Parse a list, returning a sequence of matches and using a
-        `SequenceByLine()` internally.
+        Parse a sequence of items (an item is something that would be matched
+        by `Any`), returning a sequence of matches and using a
+        stream internally.
         '''
-        return self.list_matcher(config)(list_)
+        return self.items_matcher(config, **kargs)(list_)
         
-    def match_path(self, path, config=None):
+    def match_path(self, path, config=None, **kargs):
         '''
         Parse a file, returning a sequence of matches and using a
-        `SequenceByLine()` internally.
+        stream internally.
         '''
-        return self.path_matcher(config)(path)
+        return self.path_matcher(config, **kargs)(path)
         
-    def match_string(self, string, config=None):
+    def match_string(self, string, config=None, **kargs):
         '''
         Parse a string, returning a sequence of matches and using a
-        `SequenceByLine()` internally.
+        stream internally.
         '''
-        return self.string_matcher(config)(string)
+        return self.string_matcher(config, **kargs)(string)
 
-    def match(self, stream, config=None):
+    def match(self, stream, config=None, **kargs):
         '''
         Parse a string or list, returning a sequence of matches 
         (this does not use streams).
         '''
-        return self.null_matcher(config)(stream)
+        return self.null_matcher(config, **kargs)(stream)
     
 
 class Transformation(object):
@@ -369,7 +374,8 @@ class _BaseSearch(OperatorMatcher):
         self._arg(stop=stop)
         self._karg(rest=coerce_(first if rest is None else rest))
         
-    def _cleanup(self, queue):
+    @staticmethod
+    def _cleanup(queue):
         '''
         Utility called by subclasses.
         '''
@@ -585,7 +591,8 @@ class First(_BaseCombiner):
                     matched = True
             except StopIteration:
                 pass
-            if matched: break
+            if matched:
+                break
             
 
 class Any(OperatorMatcher):
@@ -679,6 +686,8 @@ class Empty(OperatorMatcher):
         if name:
             self.tag(name)
     
+    # pylint: disable-msg=R0201
+    # keep things consistent for future subclasses
     @tagged
     def _match(self, stream):
         '''
@@ -687,8 +696,8 @@ class Empty(OperatorMatcher):
         the next.
         '''
         yield ([], stream)
-
-            
+        
+        
 class Lookahead(OperatorMatcher):
     '''
     Tests to see if the embedded matcher *could* match, but does not do the
@@ -769,6 +778,9 @@ class Transform(Transformable):
             pass
         
     def compose(self, transform):
+        '''
+        Create a new Transform that includes the extra processing. 
+        '''
         return Transform(self.matcher, 
                          self.function.compose(transform.function))
 
@@ -801,8 +813,8 @@ class Regexp(OperatorMatcher):
         (result, stream) tuples).
         '''
         try:
-            match = self.__pattern.match(stream.text())
-        except: # no text method
+            match = self.__pattern.match(stream.text)
+        except AttributeError: # no text method
             match = self.__pattern.match(stream)
         if match:
             eaten = len(match.group())
@@ -818,6 +830,8 @@ class Delayed(OperatorMatcher):
     matcher must be assigned via '+='.
     '''
     
+    __count = 0 # used to order instances by time when += called
+    
     def __init__(self, matcher=None):
         '''
         Introduce the matcher.  It can be defined later with '+='
@@ -835,13 +849,16 @@ class Delayed(OperatorMatcher):
         else:
             raise ValueError('Delayed matcher still unbound.')
         
+    # pylint: disable-msg=E0203, W0201
+    # _karg defined this in constructor
     def __iadd__(self, matcher):
         if self.matcher:
             raise ValueError('Delayed matcher already bound.')
         else:
             self.matcher = coerce_(matcher)
+            self.count = self.__count
             return self
-         
+        
 
 class Commit(OperatorMatcher):
     '''
@@ -854,8 +871,10 @@ class Commit(OperatorMatcher):
         super(Commit, self).__init__()
         self.monitor_class = _GeneratorManager
     
+    # pylint: disable-msg=R0201
+    # consistent for subclasses
     @tagged
-    def _match(self, stream):
+    def _match(self, _stream):
         '''
         Attempt to match the stream.
         '''
@@ -919,6 +938,8 @@ class Eof(OperatorMatcher):
     def __init__(self):
         super(Eof, self).__init__()
 
+    # pylint: disable-msg=R0201
+    # consistent for subclasses
     @tagged
     def _match(self, stream):
         '''
@@ -939,7 +960,7 @@ class Consumer(OperatorMatcher):
         '''
         super(Consumer, self).__init__()
         self._arg(matcher=coerce_(matcher))
-        self._arg(consume=consume)
+        self._karg(consume=consume)
     
     @tagged
     def _match(self, stream_in):
