@@ -90,7 +90,8 @@ class Node(LogMixin, ConstructorGraphNode):
         '''
         The names of all the attributes constructed from the results.
         '''
-        return iter(self.__names)
+        # this must return a list, not an iterator (Python requirement)
+        return list(self.__names)
     
     def __getitem__(self, index):
         return self.__children[index]
@@ -100,7 +101,7 @@ class Node(LogMixin, ConstructorGraphNode):
     
     def __str__(self):
         visitor = NodeTreeStr()
-        return visitor.postprocess(self.__postorder(visitor))
+        return self.__postorder(visitor)
     
     def __repr__(self):
         return self.__class__.__name__ + '(...)'
